@@ -1,6 +1,6 @@
 # In --strict mode, mypy complains about imports unless they're done this way.
 #
-# It complains 'Module has no attribute ABC' or 'Module "mango" does not explicitly export
+# It complains 'Module has no attribute ABC' or 'Module "entropy" does not explicitly export
 # attribute "XYZ"; implicit reexport disabled'. We could dial that back by using the
 # --implicit-reexport parameter, but let's keep things strict.
 #
@@ -53,7 +53,7 @@ from .client import (
 from .client import TransactionException as TransactionException
 from .client import TransactionMonitor as TransactionMonitor
 from .combinableinstructions import CombinableInstructions as CombinableInstructions
-from .constants import MangoConstants as MangoConstants
+from .constants import EntropyConstants as EntropyConstants
 from .constants import PackageVersion as PackageVersion
 from .constants import DATA_PATH as DATA_PATH
 from .constants import I64_MAX as I64_MAX
@@ -90,52 +90,54 @@ from .instructionreporter import (
     CompoundInstructionReporter as CompoundInstructionReporter,
 )
 from .instructionreporter import InstructionReporter as InstructionReporter
-from .instructionreporter import MangoInstructionReporter as MangoInstructionReporter
+from .instructionreporter import (
+    EntropyInstructionReporter as EntropyInstructionReporter,
+)
 from .instructionreporter import SerumInstructionReporter as SerumInstructionReporter
 from .instructions import (
-    build_mango_cache_perp_markets_instructions as build_mango_cache_perp_markets_instructions,
+    build_entropy_cache_perp_markets_instructions as build_entropy_cache_perp_markets_instructions,
 )
 from .instructions import (
-    build_mango_cache_prices_instructions as build_mango_cache_prices_instructions,
+    build_entropy_cache_prices_instructions as build_entropy_cache_prices_instructions,
 )
 from .instructions import (
-    build_mango_cache_root_banks_instructions as build_mango_cache_root_banks_instructions,
+    build_entropy_cache_root_banks_instructions as build_entropy_cache_root_banks_instructions,
 )
 from .instructions import (
-    build_mango_create_account_instructions as build_mango_create_account_instructions,
+    build_entropy_create_account_instructions as build_entropy_create_account_instructions,
 )
 from .instructions import (
-    build_mango_deposit_instructions as build_mango_deposit_instructions,
+    build_entropy_deposit_instructions as build_entropy_deposit_instructions,
 )
 from .instructions import (
-    build_mango_redeem_accrued_instructions as build_mango_redeem_accrued_instructions,
+    build_entropy_redeem_accrued_instructions as build_entropy_redeem_accrued_instructions,
 )
 from .instructions import (
-    build_mango_register_referrer_id_instructions as build_mango_register_referrer_id_instructions,
+    build_entropy_register_referrer_id_instructions as build_entropy_register_referrer_id_instructions,
 )
 from .instructions import (
-    build_mango_set_account_delegate_instructions as build_mango_set_account_delegate_instructions,
+    build_entropy_set_account_delegate_instructions as build_entropy_set_account_delegate_instructions,
 )
 from .instructions import (
-    build_mango_set_referrer_memory_instructions as build_mango_set_referrer_memory_instructions,
+    build_entropy_set_referrer_memory_instructions as build_entropy_set_referrer_memory_instructions,
 )
 from .instructions import (
-    build_mango_settle_fees_instructions as build_mango_settle_fees_instructions,
+    build_entropy_settle_fees_instructions as build_entropy_settle_fees_instructions,
 )
 from .instructions import (
-    build_mango_settle_pnl_instructions as build_mango_settle_pnl_instructions,
+    build_entropy_settle_pnl_instructions as build_entropy_settle_pnl_instructions,
 )
 from .instructions import (
-    build_mango_update_funding_instructions as build_mango_update_funding_instructions,
+    build_entropy_update_funding_instructions as build_entropy_update_funding_instructions,
 )
 from .instructions import (
-    build_mango_update_root_bank_instructions as build_mango_update_root_bank_instructions,
+    build_entropy_update_root_bank_instructions as build_entropy_update_root_bank_instructions,
 )
 from .instructions import (
-    build_mango_unset_account_delegate_instructions as build_mango_unset_account_delegate_instructions,
+    build_entropy_unset_account_delegate_instructions as build_entropy_unset_account_delegate_instructions,
 )
 from .instructions import (
-    build_mango_withdraw_instructions as build_mango_withdraw_instructions,
+    build_entropy_withdraw_instructions as build_entropy_withdraw_instructions,
 )
 from .instructions import (
     build_perp_cancel_all_orders_instructions as build_perp_cancel_all_orders_instructions,
@@ -208,7 +210,7 @@ from .logmessages import expand_log_messages as expand_log_messages
 from .lotsizeconverter import LotSizeConverter as LotSizeConverter
 from .lotsizeconverter import NullLotSizeConverter as NullLotSizeConverter
 from .lotsizeconverter import RaisingLotSizeConverter as RaisingLotSizeConverter
-from .mangoinstruction import MangoInstruction as MangoInstruction
+from .entropyinstruction import EntropyInstruction as EntropyInstruction
 from .marketlookup import CompoundMarketLookup as CompoundMarketLookup
 from .marketlookup import MarketLookup as MarketLookup
 from .marketlookup import NullMarketLookup as NullMarketLookup
@@ -363,7 +365,7 @@ from .transactionscout import (
     fetch_all_recent_transaction_signatures as fetch_all_recent_transaction_signatures,
 )
 from .transactionscout import (
-    mango_instruction_from_response as mango_instruction_from_response,
+    entropy_instruction_from_response as entropy_instruction_from_response,
 )
 from .version import Version as Version
 from .wallet import Wallet as Wallet
